@@ -21,6 +21,7 @@ from uuid import uuid4
 
 import click
 import requests
+import sentry_sdk
 from fastapi.encoders import jsonable_encoder
 from integrations import cpr_mapper
 from integrations.ad_integration import ad_reader
@@ -720,6 +721,13 @@ class ChangeAtSD:
             fix_date = today + datetime.timedelta(weeks=80)
             self.department_fixer.fix_department(org_unit, fix_date)
             ou_info = self.helper.read_ou(org_unit, use_cache=False)
+            if "status" in ou_info:
+                # TODO: This code should be removed once the 80-week magic number
+                #       is eliminated, right now it serves to ensure solely that
+                #       the SD integration does not crash due to the bad code.
+                #       The solution will then be to fix all the issues using SDTool.
+                logger.warning("Unable to apply NY-logic", org_unit)
+                return org_unit
 
         if ou_info["org_unit_level"]["user_key"] in too_deep:
             self.create_association(org_unit, person_uuid, job_id, validity)
@@ -1458,6 +1466,9 @@ def changed_at(init: bool, force: bool, from_date: Optional[datetime.datetime] =
 
     run_db = settings.sd_import_run_db
 
+    if settings.sentry_dsn:
+        sentry_sdk.init(dsn=settings.sentry_dsn)
+
     logger.info("***************")
     logger.info("Program started")
 
@@ -1521,32 +1532,5 @@ def import_single_user(cpr: str, from_date: datetime.datetime, dry_run: bool):
     sd_updater.update_all_employments(cpr, dry_run=dry_run)
 
 
-@cli.command()
-@click.option(
-    "--from-date",
-    type=click.DateTime(),
-    help="Global import from-date",
-)
-@click.option(
-    "--dry-run", is_flag=True, default=False, help="Dry-run making no actual changes."
-)
-def import_state_cli(from_date: datetime.datetime, dry_run: bool):
-    """Import engagement changes for all users."""
-    import_state(from_date, dry_run)
-
-
-def import_state(from_date: Optional[datetime.datetime] = None, dry_run: bool = False):
-    """Import engagement changes for all users."""
-    settings = get_changed_at_settings()
-    setup_logging(settings.sd_log_file)
-
-    if not from_date:
-        from_date = date_to_datetime(settings.sd_global_from_date)
-
-    sd_updater = ChangeAtSD(settings, from_date, None)
-    sd_updater.update_changed_persons(dry_run=dry_run)
-    sd_updater.update_all_employments(dry_run=dry_run)
-
-
 if __name__ == "__main__":
     cli()
