@@ -19,6 +19,8 @@ from integrations.ad_integration import ad_reader
 from os2mo_data_import import ImportHelper
 from os2mo_helpers.mora_helpers import MoraHelper
 
+from .fix_departments import FixDepartments
+from .config import get_changed_at_settings
 from .config import get_importer_settings
 from .config import ImporterSettings
 from .date_utils import format_date, date_to_datetime
@@ -64,11 +66,13 @@ class SdImport:
         self.importer = importer
 
         self.org_name = self.settings.municipality_name
+        self.sd_institution_uuid = self._get_institution()
 
         self.importer.add_organisation(
             identifier=self.org_name,
             user_key=self.org_name,
             municipality_code=self.settings.municipality_code,
+            uuid=str(self.sd_institution_uuid),
         )
 
         self.org_id_prefix = org_id_prefix
@@ -376,6 +380,14 @@ class SdImport:
                 super_unit=super_unit,
             )
 
+    def _get_institution(self) -> uuid.UUID:
+        params = {
+            "InstitutionIdentifier": self.settings.sd_institution_identifier,
+            "UUIDIndicator": "true",
+        }
+        r = sd_lookup("GetInstitution20111201", settings=self.settings, params=params)
+        return uuid.UUID(r["Region"]["Institution"]["InstitutionUUIDIdentifier"])
+
     def _create_org_tree_structure(self):
         nodes = {}
         all_ous = self.importer.export("organisation_unit")
