@@ -9,17 +9,18 @@ from typing import Optional
 from typing import Tuple
 
 import click
+import sentry_sdk
 from more_itertools import only
 from more_itertools import partition
 from os2mo_helpers.mora_helpers import MoraHelper
 from ra_utils.apply import apply
 from ra_utils.jinja_filter import create_filters
 from ra_utils.load_settings import load_settings
+from ra_utils.tqdm_wrapper import tqdm
 
 from .ad_logger import start_logging
 from .ad_reader import ADParameterReader
 from exporters.sql_export.lora_cache import LoraCache
-from helpers import tqdm
 
 logger = logging.getLogger("AdSyncRead")
 
@@ -853,6 +854,10 @@ class AdMoSync:
 )
 def sync(sync_user):
     sync = AdMoSync()
+
+    if "crontab.SENTRY_DSN" in sync.settings:
+        sentry_sdk.init(dsn=sync.settings["crontab.SENTRY_DSN"])
+
     if sync_user:
         sync.update_single_user(str(sync_user))
     else:
@@ -861,5 +866,4 @@ def sync(sync_user):
 
 if __name__ == "__main__":
     start_logging("ad_mo_sync.log")
-
     sync()
